@@ -184,14 +184,14 @@ class TestCollection(unittest.TestCase):
         db.test.drop_index("goodbye_1")
         self.assertEqual("goodbye_1",
                          db.test.ensure_index("goodbye", cache_for=1))
-        time.sleep(1.1)
+        time.sleep(1.2)
         self.assertEqual("goodbye_1",
                          db.test.ensure_index("goodbye"))
 
         db.test.drop_index("goodbye_1")
         self.assertEqual("goodbye_1",
                          db.test.create_index("goodbye", cache_for=1))
-        time.sleep(1.1)
+        time.sleep(1.2)
         self.assertEqual("goodbye_1",
                          db.test.ensure_index("goodbye"))
         # Make sure the expiration time is updated.
@@ -416,8 +416,9 @@ class TestCollection(unittest.TestCase):
                 "coordinates": [[[40,5], [40,6], [41,6], [41,5], [40,5]]]}
         query = {"geo": {"$within": {"$geometry": poly}}}
 
-        self.assertEqual("S2Cursor",
-                         db.test.find(query).explain()['cursor'])
+        self.assertTrue(
+            db.test.find(query).explain()['cursor'].startswith('S2Cursor'))
+
         db.test.drop_indexes()
 
     def test_index_hashed(self):
@@ -1046,7 +1047,7 @@ class TestCollection(unittest.TestCase):
             None, db.test.update({"_id": id}, {"$inc": {"x": 1}}, w=0))
 
         if v19:
-            self.assertTrue(db.error()["err"].startswith("E11000"))
+            self.assertTrue("E11000" in db.error()["err"])
         elif v113minus:
             self.assertTrue(db.error()["err"].startswith("E11001"))
         else:
@@ -1699,6 +1700,14 @@ class TestCollection(unittest.TestCase):
         c.drop()
         c.insert({'_id': 1, 'i': 1})
 
+        # Test that we raise DuplicateKeyError when appropriate.
+        c.ensure_index('i', unique=True)
+        self.assertRaises(DuplicateKeyError,
+                          c.find_and_modify, query={'i': 1, 'j': 1},
+                          update={'$set': {'k': 1}}, upsert=True)
+        c.drop_indexes()
+
+        # Test correct findAndModify
         self.assertEqual({'_id': 1, 'i': 1},
                          c.find_and_modify({'_id': 1}, {'$inc': {'i': 1}}))
         self.assertEqual({'_id': 1, 'i': 3},
